@@ -33,8 +33,6 @@ class DBClient:
             self.connect()
             self._cursor.execute(SQL_command, params=params)
             self._connector.commit()
-            row_id = self._cursor.lastrowid
-            return row_id
         except Exception:
             traceback.print_exc()
         finally:
